@@ -4,77 +4,78 @@ use rucash::Book;
 const URI: &str = "sqlite://tests/db/sqlite/complex_sample.gnucash";
 
 type DB = sqlx::Sqlite;
+type RAW = rucash::Ignore;
 mod book {
     use super::*;
 
     #[test]
     fn new() {
-        Book::<DB>::new(URI).unwrap();
+        Book::<DB, RAW>::new(URI).unwrap();
     }
 
     #[test]
     #[should_panic]
     fn new_fail() {
-        Book::<DB>::new("sqlite://tests/sample/no.gnucash").unwrap();
+        Book::<DB, RAW>::new("sqlite://tests/sample/no.gnucash").unwrap();
     }
 
     #[test]
     fn accounts_filter() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let accounts: Vec<Account> = book
             .accounts()
             .unwrap()
             .into_iter()
-            .filter(|x| x.name.to_lowercase().contains("as"))
+            .filter(|x| x.name.to_lowercase().contains(&"aS".to_lowercase()))
             .collect();
         assert_eq!(accounts.len(), 3);
     }
 
     #[test]
     fn accounts_by_name() {
-        let book = Book::<DB>::new(URI).unwrap();
-        let accounts = book.accounts_contains_name("as").unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let accounts = book.accounts_contains_name("aS").unwrap();
         assert_eq!(accounts.len(), 3);
     }
 
     #[test]
     fn account_by_name() {
-        let book = Book::<DB>::new(URI).unwrap();
-        let account = book.account_by_name("as").unwrap().unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let account = book.account_by_name("aS").unwrap().unwrap();
         assert_eq!(account.name, "NASDAQ");
     }
 
     #[test]
     fn splits() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let splits = book.splits().unwrap();
         assert_eq!(splits.len(), 25);
     }
 
     #[test]
     fn transactions() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let transactions = book.transactions().unwrap();
         assert_eq!(transactions.len(), 11);
     }
 
     #[test]
     fn prices() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let prices = book.prices().unwrap();
         assert_eq!(prices.len(), 5);
     }
 
     #[test]
     fn commodities() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodities = book.commodities().unwrap();
         assert_eq!(commodities.len(), 5);
     }
 
     #[test]
     fn currencies() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let currencies = book.currencies().unwrap();
         assert_eq!(currencies.len(), 4);
     }
@@ -83,7 +84,7 @@ mod account {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -113,7 +114,7 @@ mod account {
 
     #[test]
     fn balance() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -126,7 +127,7 @@ mod account {
     }
     #[test]
     fn balance_diff_currency() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -139,7 +140,7 @@ mod account {
     }
     #[test]
     fn splits() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let splits = account.splits().unwrap();
         assert_eq!(splits.len(), 3);
@@ -147,7 +148,7 @@ mod account {
 
     #[test]
     fn parent() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let parent = account.parent().unwrap();
         assert_eq!(parent.name, "Current");
@@ -155,7 +156,7 @@ mod account {
 
     #[test]
     fn no_parent() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book.account_by_name("Root Account").unwrap().unwrap();
         let parent = account.parent();
         assert!(parent.is_none());
@@ -163,7 +164,7 @@ mod account {
 
     #[test]
     fn children() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book.account_by_name("Current").unwrap().unwrap();
         let children = account.children().unwrap();
         assert_eq!(children.len(), 3);
@@ -171,7 +172,7 @@ mod account {
 
     #[test]
     fn commodity() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let commodity = account.commodity().unwrap();
         assert_eq!(commodity.mnemonic, "EUR");
@@ -182,7 +183,7 @@ mod split {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -216,7 +217,7 @@ mod split {
     }
     #[test]
     fn transaction() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -230,7 +231,7 @@ mod split {
 
     #[test]
     fn account() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -247,7 +248,7 @@ mod transaction {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -285,7 +286,7 @@ mod transaction {
 
     #[test]
     fn currency() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -299,7 +300,7 @@ mod transaction {
 
     #[test]
     fn splits() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -316,7 +317,7 @@ mod price {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -341,7 +342,7 @@ mod price {
 
     #[test]
     fn commodity() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -355,7 +356,7 @@ mod price {
 
     #[test]
     fn currency() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -372,7 +373,7 @@ mod commodity {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -394,7 +395,7 @@ mod commodity {
 
     #[test]
     fn accounts() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -408,7 +409,7 @@ mod commodity {
 
     #[test]
     fn transactions() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -422,7 +423,7 @@ mod commodity {
 
     #[test]
     fn as_commodity_prices() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -436,7 +437,7 @@ mod commodity {
 
     #[test]
     fn as_currency_prices() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -450,7 +451,7 @@ mod commodity {
 
     #[test]
     fn as_commodity_or_currency_prices() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -465,7 +466,7 @@ mod commodity {
     #[test]
     fn rate_direct() {
         // ADF => AED
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -487,7 +488,7 @@ mod commodity {
         assert_eq!(rate, 1.0 / 1.5);
 
         // AED => EUR
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -511,7 +512,7 @@ mod commodity {
 
     #[test]
     fn rate_indirect() {
-        let book = Book::<DB>::new(URI).unwrap();
+        let book = Book::<DB, RAW>::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
